@@ -157,6 +157,7 @@ class NumerousBufferedWriter:
 
         self.closed = True
 
+
 class NumerousLogHandler:
     def __init__(self, client):
         self.client = client
@@ -164,14 +165,15 @@ class NumerousLogHandler:
     def handle(self, record):
         self.client.push_scenario_log(record.msg)
 
-    #TODO make a handler thread to schedule update to server!
+    # TODO make a handler thread to schedule update to server!
+
 
 class NumerousClient:
     def __init__(self, job_id=None, project=None, scenario=None, server=None, port=None, refresh_token=None, clear_data=None, no_log=False, instance_id=None, secure=None):
         self.job_states = JobStatus
         self._project = get_env(project, 'NUMEROUS_PROJECT')
         self._scenario = get_env(scenario, 'NUMEROUS_SCENARIO')
-        self._spm_job_id = get_env(job_id, 'SPM_JOB_ID')
+        self._job_id = get_env(job_id, 'JOB_ID')
         self._refresh_token = get_env(refresh_token, 'NUMEROUS_API_REFRESH_TOKEN')
         self._access_token = None
 
@@ -179,20 +181,15 @@ class NumerousClient:
         self._execution_id = get_env(None, 'NUMEROUS_EXECUTION_ID', 'not_found')
         if self._execution_id == 'not_found' or self._execution_id is None:
             self._execution_id = str(uuid4())
-            print("EX", self._execution_id)
             log.debug(f'No execution id found - generating new: {self._execution_id}')
 
         self._complete = True
         self.writers = []
 
-
-        channel = self._init_channel(server=server, port=port, secure=secure, instance_id=self._instance_id)
-        stub = spm_pb2_grpc.SPMStub(channel)
-
-        # TODO: Maybe reconsider both of these!
-        self._job_manager = spm_pb2_grpc.JobManagerStub(channel)
-        self._token_manager = spm_pb2_grpc.TokenManagerStub(channel)
-        self._base_client = stub
+        self.channel = self._init_channel(server=server, port=port, secure=secure, instance_id=self._instance_id)
+        self.stub = spm_pb2_grpc.SPMStub(self.channel)
+        self._token_manager = spm_pb2_grpc.TokenManagerStub(self.channel)
+        self._base_client = self.stub
 
         # Refresh token every 9 minutes (?)
         self._access_token_refresher = RepeatedFunction(
@@ -222,7 +219,7 @@ class NumerousClient:
         self._listen.start()
 
     def complete_execution(self):
-        self._base_client.CompleteExecution(spm_pb2.ExecutionMessage(project_id=self._project, scenario_id=self._scenario, job_id=self._spm_job_id, execution_id=self._execution_id))
+        self._base_client.CompleteExecution(spm_pb2.ExecutionMessage(project_id=self._project, scenario_id=self._scenario, job_id=self._job_id, execution_id=self._execution_id))
 
     def _init_channel(self, server, port, secure=None, instance_id=None):
         secure_channel = get_env(secure, 'SECURE_CHANNEL')
@@ -258,17 +255,15 @@ class NumerousClient:
         self.log_listener.start()
 
     def _refresh_access_token(self, refresh_token, instance_id, execution_id):
-        print("REFRESH TOKEN", refresh_token)
         token = self._token_manager.GetAccessToken(
             spm_pb2.RefreshRequest(
                 refresh_token=spm_pb2.Token(val=refresh_token), instance_id=instance_id, execution_id=execution_id
             )
         )
-        print(f"TOKEN REFRESHED: {token.val}")
         self._access_token = token.val
 
     def _listen_terminate(self):
-       for channel, message in self.subscribe_messages([".".join(['COMMAND', self._project, self._scenario, self._spm_job_id])]):
+       for channel, message in self.subscribe_messages([".".join(['COMMAND', self._project, self._scenario, self._job_id])]):
             log.debug('Received message: '+str(message)+'\n on channel: '+str(channel))
             if 'command' in message:
                 command = message['command']
@@ -289,7 +284,7 @@ class NumerousClient:
         if scenario_doc is None:
             scenario_doc, files = self.get_scenario_document()
 
-        return scenario_doc['jobs'][self._spm_job_id]
+        return scenario_doc['jobs'][self._job_id]
 
 
     def get_group_document(self, group):
@@ -363,7 +358,7 @@ class NumerousClient:
 
             self.last_progress=tic
             self._base_client.SetScenarioProgress(spm_pb2.ScenarioProgress(
-                project=self._project, scenario=scenario, spm_job_id=self._spm_job_id,
+                project=self._project, scenario=scenario, spm_job_id=self._job_id,
                 message=message, status=status, clean=clean, progress=progress
             ))
 
@@ -391,7 +386,7 @@ class NumerousClient:
         if scenario is None:
             scenario = self._scenario
 
-        self._base_client.PushScenarioError(spm_pb2.ScenarioError(project=self._project, scenario=scenario, error=error, spm_job_id=self._spm_job_id))
+        self._base_client.PushScenarioError(spm_pb2.ScenarioError(project=self._project, scenario=scenario, error=error, spm_job_id=self._job_id))
 
     def push_scenario_log(self, message, initialize=False, scenario=None):
         if scenario is None:
@@ -399,7 +394,7 @@ class NumerousClient:
 
         self._base_client.PushScenarioLogEntry(spm_pb2.ScenarioLogEntry(
             project=self._project, scenario=scenario, message=message,
-            spm_job_id=self._spm_job_id, initialize=initialize
+            spm_job_id=self._job_id, initialize=initialize
         ))
 
     def push_scenario_logs(self, logs):
@@ -992,60 +987,24 @@ class RepeatedFunction:
         self._timer.cancel()
         self.is_running = False
 
+class Test(NumerousClient):
+    def __init__(self):
+        super(Test, self).__init__()
+
 
 class NumerousAdminClient(NumerousClient):
     def __init__(self, server=None, port=None, secure=None, refresh_token=None, instance_id=None):
-        self.writers = []
-        self._user = 'test_user'
-        self._organization = 'EnergyMachines'
-        self._execution_id = get_env(None, 'NUMEROUS_EXECUTION_ID', 'not_found')
-
-#        self._token = get_env(token, 'NUMEROUS_API_TOKEN')
-        self._access_token = None
-        self._refresh_token = get_env(refresh_token, 'NUMEROUS_API_REFRESH_TOKEN')
-        self._instance_id = str(uuid4()) if instance_id is None else instance_id
-        secure = get_env(secure, 'SECURE_CHANNEL')
-
-        channel = self._init_channel(server=server, port=port, secure=secure)
-        stub = spm_pb2_grpc.SPMStub(channel)
-        self._token_manager = spm_pb2_grpc.TokenManagerStub(channel)
-
-        # Refresh token every 9 minutes (?)
-        self._access_token_refresher = RepeatedFunction(
-            interval=9 * 60, function=self._refresh_access_token, run_initially=True,
-            refresh_token=self._refresh_token, instance_id=self._instance_id, execution_id=self._execution_id
+        super(NumerousAdminClient, self).__init__(
+            server=server, port=port, secure=secure, refresh_token=refresh_token, instance_id=instance_id
         )
-        self._access_token_refresher.start()
-
-
-
-
-        # TODO: Maybe reconsider
-        self._job_manager = spm_pb2_grpc.JobManagerStub(channel)
-
-        self._base_client = stub
+        self._job_manager = spm_pb2_grpc.JobManagerStub(self.channel)
         self._terminated = False
         self._complete = False
-
-        self._execution_id = get_env(None, 'NUMEROUS_EXECUTION_ID', 'not_found')
-        if self._execution_id == 'not_found' or self._execution_id is None:
-            self._execution_id = str(uuid4())
-            log.debug(f'No execution id found - generating new: {self._execution_id}')
+        self._user = 'test_user'
+        self._organization = 'EnergyMachines'
 
         log.info('init admin client')
 
-    """
-    # TODO: Remove? The client should not be allowed to stop/start instances of clients!
-    def start_image(self, scenario, image, name, namespace, spm_job_id, google_project='simulationwidgets'):
-        deployed_image = self._job_manager.StartImage(spm_pb2.ImageInformation(
-            project_id=self._project, scenario_id=scenario,
-            google_project=google_project, image=image,
-            deployment_name=name, namespace=namespace,
-            spm_job_id=spm_job_id
-        ))
-
-        return {'kubernetes_id': deployed_image.kubernetes_id, 'namespace': deployed_image.namespace}"""
-
     def launch_job(self, project, scenario, job):
         self._job_manager.StartJob(spm_pb2.Job(
             project_id=project, scenario_id=scenario, job_id=job, user_id=self._user, organization_id=self._organization
@@ -1093,6 +1052,7 @@ class NumerousAdminClient(NumerousClient):
         for l in self._base_client.ReadExecutionLogEntries(spm_pb2.ExecutionReadLogs(execution_id=self._execution_id, start=0.0, end=0.0)):
             yield l.log_entry, datetime.fromtimestamp(l.timestamp)
 
+
 @contextmanager
 def open_admin_client(server=None, port=None, secure=None, refresh_token=None) -> NumerousAdminClient:
     numerous_client_ = NumerousAdminClient(server=server, port=port, secure=secure, refresh_token=refresh_token)
